package App::Hasher;
$App::Hasher::VERSION = '1.0.2';
use strict;
use warnings FATAL => 'all';
use feature 'say';
use utf8;
use open qw(:std :utf8);

# ABSTRACT: script to change file name to be hash of its content


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::Hasher - script to change file name to be hash of its content

=head1 VERSION

version 1.0.2

=head1 SYNOPSIS

Please read L<hasher> documentation.

=head1 DESCRIPTION

App::Hasher version numbers uses Semantic Versioning standart.
Please visit L<http://semver.org/> to find out all about this great thing.

=head1 AUTHOR

Ivan Bessarabov <ivan@bessarabov.ru>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Ivan Bessarabov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
